aboutsummaryrefslogtreecommitdiff
path: root/plugins/Page.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/Page.hpp')
-rw-r--r--plugins/Page.hpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/plugins/Page.hpp b/plugins/Page.hpp
index a803725..6864a5d 100644
--- a/plugins/Page.hpp
+++ b/plugins/Page.hpp
@@ -67,8 +67,9 @@ namespace QuickMedia {
virtual bool is_trackable() const { return false; }
// Return nullptr if bookmark is not supported by this page
virtual const char* get_bookmark_name() const { return nullptr; }
- // If this returns nullptr then the currently selected body item is used instead
- virtual std::shared_ptr<BodyItem> get_bookmark_body_item() { return nullptr; }
+ // If this returns nullptr then the currently selected body item is used instead.
+ // |selected_item| may be nullptr.
+ virtual std::shared_ptr<BodyItem> get_bookmark_body_item(BodyItem *selected_item) { (void)selected_item; return nullptr; }
virtual bool is_bookmark_page() const { return false; }
virtual bool is_lazy_fetch_page() const { return false; }
// Note: If submit is done without any selection, then the search term is sent as the |title| and |url|. Submit will only be sent if the input text is not empty or if an item is selected
@@ -117,6 +118,7 @@ namespace QuickMedia {
// If this returns true then |lazy_fetch| is not meant to return results but async background load the page. This can be used to fetch API keys for example
virtual bool lazy_fetch_is_loader() { return false; }
virtual bool reload_on_page_change() { return false; }
+ virtual bool reseek_to_body_item_by_url() { return false; }
};
class RelatedVideosPage : public Page {